@@ -74,6 +74,7 @@ do <- function(n=1L, cull=NULL, mode=NULL) {
 	x <- gsub('shuffle\\(','', x)
 	x <- gsub('\\(','.', x)
 	x <- gsub('-','.', x)
+	x <- gsub(':','.', x)
 	x <- gsub('\\)','', x)
 	return(x)
 }
@@ -226,7 +227,8 @@ if(FALSE) {
 	if (any(class(object)=='cointoss')) {
 		return( c(n=attr(object,'n'), 
 				heads=sum(attr(object,'sequence')=='H'),
-				tails=sum(attr(object,'sequence')=='T')
+				tails=sum(attr(object,'sequence')=='T'),
+        prop=sum(attr(object,'sequence')=="H") / attr(object,'n')
 				) )
 	}
 	if (is.matrix(object) && ncol(object) == 1) {
